@@ -87,7 +87,7 @@ static char *max6data(curl_off_t bytes, char *max6)
     /* xxx.yU */
     curl_msnprintf(max6, 7, "%3" CURL_FORMAT_CURL_OFF_T
                    ".%" CURL_FORMAT_CURL_OFF_T "%c", nbytes,
-                   (bytes%1024) / (1024/10), unit[k]);
+                   (bytes % 1024) / (1024 / 10), unit[k]);
   }
   return max6;
 }
@@ -109,7 +109,7 @@ UNITTEST CURLcode pgrs_speedcheck(struct Curl_easy *data,
     /* A paused transfer is not qualified for speed checks */
     return CURLE_OK;
 
-  if((data->progress.current_speed >= 0) && data->set.low_speed_time) {
+  if(data->progress.current_speed >= 0) {
     if(data->progress.current_speed < data->set.low_speed_limit) {
       if(!data->state.keeps_speed.tv_sec)
         /* under the limit at this moment */
@@ -134,14 +134,32 @@ UNITTEST CURLcode pgrs_speedcheck(struct Curl_easy *data,
       data->state.keeps_speed.tv_sec = 0;
   }
 
-  if(data->set.low_speed_limit)
-    /* if low speed limit is enabled, set the expire timer to make this
-       connection's speed get checked again in a second */
-    Curl_expire(data, 1000, EXPIRE_SPEEDCHECK);
+  /* since low speed limit is enabled, set the expire timer to make this
+     connection's speed get checked again in a second */
+  Curl_expire(data, 1000, EXPIRE_SPEEDCHECK);
 
   return CURLE_OK;
 }
 
+void Curl_pgrs_now_set(struct Curl_easy *data)
+{
+  data->progress.now = curlx_now();
+}
+
+void Curl_pgrs_now_at_least(struct Curl_easy *data, struct curltime *pts)
+{
+  if((pts->tv_sec > data->progress.now.tv_sec) ||
+     ((pts->tv_sec == data->progress.now.tv_sec) &&
+      (pts->tv_usec > data->progress.now.tv_usec))) {
+    data->progress.now = *pts;
+  }
+}
+
+void Curl_pgrs_now_update(struct Curl_easy *data, struct Curl_easy *other)
+{
+  Curl_pgrs_now_at_least(data, &other->progress.now);
+}
+
 /*
 
    New proposed interface, 9th of February 2000:
@@ -175,7 +193,7 @@ int Curl_pgrsDone(struct Curl_easy *data)
 void Curl_pgrsReset(struct Curl_easy *data)
 {
   Curl_pgrsSetUploadCounter(data, 0);
-  Curl_pgrsSetDownloadCounter(data, 0);
+  data->progress.dl.cur_size = 0;
   Curl_pgrsSetUploadSize(data, -1);
   Curl_pgrsSetDownloadSize(data, -1);
   data->progress.speeder_c = 0; /* reset speed records */
@@ -197,6 +215,14 @@ void Curl_pgrsRecvPause(struct Curl_easy *data, bool enable)
   }
 }
 
+void Curl_pgrsSendPause(struct Curl_easy *data, bool enable)
+{
+  if(!enable) {
+    data->progress.speeder_c = 0; /* reset speed records */
+    pgrs_speedinit(data); /* reset low speed measurements */
+  }
+}
+
 /*
  *
  * Curl_pgrsTimeWas(). Store the timestamp time at the given label.
@@ -281,19 +307,17 @@ void Curl_pgrsTimeWas(struct Curl_easy *data, timerid timer,
  *
  * @unittest: 1399
  */
-struct curltime Curl_pgrsTime(struct Curl_easy *data, timerid timer)
+void Curl_pgrsTime(struct Curl_easy *data, timerid timer)
 {
-  struct curltime now = curlx_now();
-
-  Curl_pgrsTimeWas(data, timer, now);
-  return now;
+  Curl_pgrs_now_set(data); /* update on real progress */
+  Curl_pgrsTimeWas(data, timer, data->progress.now);
 }
 
 void Curl_pgrsStartNow(struct Curl_easy *data)
 {
   struct Progress *p = &data->progress;
   p->speeder_c = 0; /* reset the progress meter display */
-  p->start = curlx_now();
+  p->start = data->progress.now;
   p->is_t_startransfer_set = FALSE;
   p->dl.cur_size = 0;
   p->ul.cur_size = 0;
@@ -302,12 +326,20 @@ void Curl_pgrsStartNow(struct Curl_easy *data)
   p->ul_size_known = FALSE;
 }
 
-/*
- * Set the number of downloaded bytes so far.
- */
-void Curl_pgrsSetDownloadCounter(struct Curl_easy *data, curl_off_t size)
+void Curl_pgrs_download_inc(struct Curl_easy *data, size_t delta)
 {
-  data->progress.dl.cur_size = size;
+  if(delta) {
+    data->progress.dl.cur_size += delta;
+    Curl_rlimit_drain(&data->progress.dl.rlimit, delta, &data->progress.now);
+  }
+}
+
+void Curl_pgrs_upload_inc(struct Curl_easy *data, size_t delta)
+{
+  if(delta) {
+    data->progress.ul.cur_size += delta;
+    Curl_rlimit_drain(&data->progress.ul.rlimit, delta, &data->progress.now);
+  }
 }
 
 /*
@@ -344,7 +376,7 @@ void Curl_pgrsSetUploadSize(struct Curl_easy *data, curl_off_t size)
 
 void Curl_pgrsEarlyData(struct Curl_easy *data, curl_off_t sent)
 {
-    data->progress.earlydata_sent = sent;
+  data->progress.earlydata_sent = sent;
 }
 
 /* returns the average speed in bytes / second */
@@ -353,7 +385,7 @@ static curl_off_t trspeed(curl_off_t size, /* number of bytes */
 {
   if(us < 1)
     return size * 1000000;
-  else if(size < CURL_OFF_T_MAX/1000000)
+  else if(size < CURL_OFF_T_MAX / 1000000)
     return (size * 1000000) / us;
   else if(us >= 1000000)
     return size / (us / 1000000);
@@ -415,18 +447,18 @@ static bool progress_calc(struct Curl_easy *data, struct curltime *pnow)
              ((i_latest + 1) % CURL_SPEED_RECORDS);
 
   /* How much we transferred between oldest and current records */
-  amount = p->speed_amount[i_latest]- p->speed_amount[i_oldest];
+  amount = p->speed_amount[i_latest] - p->speed_amount[i_oldest];
   /* How long this took */
   duration_ms = curlx_timediff_ms(p->speed_time[i_latest],
                                   p->speed_time[i_oldest]);
   if(duration_ms <= 0)
     duration_ms = 1;
 
-  if(amount > (CURL_OFF_T_MAX/1000)) {
+  if(amount > (CURL_OFF_T_MAX / 1000)) {
     /* the 'amount' value is bigger than would fit in 64 bits if
        multiplied with 1000, so we use the double math for this */
-    p->current_speed = (curl_off_t)
-      (((double)amount * 1000.0)/(double)duration_ms);
+    p->current_speed =
+      (curl_off_t)(((double)amount * 1000.0) / (double)duration_ms);
   }
   else {
     /* the 'amount' value is small enough to fit within 32 bits even
@@ -452,7 +484,7 @@ static curl_off_t pgrs_est_percent(curl_off_t total, curl_off_t cur)
   if(total > 10000)
     return cur / (total / 100);
   else if(total > 0)
-    return (cur*100) / total;
+    return (cur * 100) / total;
   return 0;
 }
 
@@ -481,7 +513,7 @@ static void progress_meter(struct Curl_easy *data)
   char time_left[10];
   char time_total[10];
   char time_spent[10];
-  curl_off_t cur_secs = (curl_off_t)p->timespent/1000000; /* seconds */
+  curl_off_t cur_secs = (curl_off_t)p->timespent / 1000000; /* seconds */
 
   if(!p->headers_out) {
     if(data->state.resume_from) {
@@ -509,11 +541,9 @@ static void progress_meter(struct Curl_easy *data)
   time2str(time_spent, cur_secs);
 
   /* Get the total amount of data expected to get transferred */
-  total_expected_size =
-    p->ul_size_known ? p->ul.total_size : p->ul.cur_size;
+  total_expected_size = p->ul_size_known ? p->ul.total_size : p->ul.cur_size;
 
-  dl_size =
-    p->dl_size_known ? p->dl.total_size : p->dl.cur_size;
+  dl_size = p->dl_size_known ? p->dl.total_size : p->dl.cur_size;
 
   /* integer overflow check */
   if((CURL_OFF_T_MAX - total_expected_size) < dl_size)
@@ -554,7 +584,6 @@ static void progress_meter(struct Curl_easy *data)
 #define progress_meter(x) Curl_nop_stmt
 #endif
 
-
 /*
  * Curl_pgrsUpdate() returns 0 for success or the value returned by the
  * progress callback!
@@ -614,18 +643,16 @@ static CURLcode pgrs_update(struct Curl_easy *data, struct curltime *pnow)
 
 CURLcode Curl_pgrsUpdate(struct Curl_easy *data)
 {
-  struct curltime now = curlx_now(); /* what time is it */
-  return pgrs_update(data, &now);
+  return pgrs_update(data, &data->progress.now);
 }
 
 CURLcode Curl_pgrsCheck(struct Curl_easy *data)
 {
-  struct curltime now = curlx_now();
   CURLcode result;
 
-  result = pgrs_update(data, &now);
+  result = pgrs_update(data, &data->progress.now);
   if(!result && !data->req.done)
-    result = pgrs_speedcheck(data, &now);
+    result = pgrs_speedcheck(data, &data->progress.now);
   return result;
 }
 
@@ -634,6 +661,5 @@ CURLcode Curl_pgrsCheck(struct Curl_easy *data)
  */
 void Curl_pgrsUpdate_nometer(struct Curl_easy *data)
 {
-  struct curltime now = curlx_now(); /* what time is it */
-  (void)progress_calc(data, &now);
+  (void)progress_calc(data, &data->progress.now);
 }
